#define _GNU_SOURCE
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include <errno.h>

#include "uhumenu.h"

static void indent (FILE *f, int n)
{
	int i;
	for (i = 0; i < n; i++) fprintf(f, "\t");
}

static void dump (FILE *f, const struct menu *menu, const char *lang, iconv_t ic, int n)
{
	int i;
	for (i = 0; i < menu->nr; i++) {
		if (!menu->items[i].issubmenu) {
			indent(f, n);
			fprintf(f, "[exec] (%s) {%s%s}\n",
			  get_name_locale(&menu->items[i], lang, ic),
			  menu->items[i].terminal ? "xterm -e " : "",
			  get_value(&menu->items[i], "Exec"));
		} else {
			indent(f, n);
			fprintf(f, "[submenu] (%s)\n",
			  get_name_locale(&menu->items[i], lang, ic));
			dump(f, menu->items[i].submenu, lang, ic, n+1);
			indent(f, n);
			fprintf(f, "[end]\n");
		}
	}
}

int write_menu_lang (const struct menu *menu, const char *path,
  const char *lang, iconv_t ic)
{
	char file[PATH_MAX];
	FILE *f;

	sprintf(file, "%s/%s", path, lang);
	if ((f = fopen(file, "w")) == NULL) {
		fprintf(stderr, "blackbox: fopen %s: %s\n", file, strerror(errno));
		return -1;
	}
	if (menu->nr > 0) dump(f, menu->items[0].submenu, lang, ic, 0);
	fclose(f);
	return 0;
}

